<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>AvancedQFile</name>
    <message>
        <location filename="../../AvancedQFile.cpp" line="26"/>
        <location filename="../../AvancedQFile.cpp" line="57"/>
        <location filename="../../AvancedQFile.cpp" line="88"/>
        <source>Not supported on this platform</source>
        <translation>Nem támogatott ezen a platformon</translation>
    </message>
    <message>
        <location filename="../../AvancedQFile.cpp" line="40"/>
        <source>Last modified date is wrong</source>
        <translation>A módosítás utolsó dátuma hibás</translation>
    </message>
    <message>
        <location filename="../../AvancedQFile.cpp" line="71"/>
        <source>Last access date is wrong</source>
        <translation>A hozzáférés utolsó dátuma hibása</translation>
    </message>
    <message>
        <location filename="../../AvancedQFile.cpp" line="121"/>
        <source>Unknown error: %1</source>
        <translation>Ismeretlen hiba: %1</translation>
    </message>
    <message>
        <location filename="../../AvancedQFile.cpp" line="133"/>
        <source>Path conversion error</source>
        <translation>Útvonal konvertálási hiba</translation>
    </message>
    <message>
        <location filename="../../AvancedQFile.cpp" line="187"/>
        <source>Unknown error</source>
        <translation>Ismeretlen hiba</translation>
    </message>
</context>
<context>
    <name>CopyEngine</name>
    <message>
        <location filename="../../CopyEngine.cpp" line="429"/>
        <location filename="../../CopyEngine.cpp" line="451"/>
        <source>The engine is forced to move, you can&apos;t copy with it</source>
        <translation>A motort mozgatásra kényszerítik, nem másolhatsz vele</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="462"/>
        <location filename="../../CopyEngine.cpp" line="484"/>
        <source>The engine is forced to copy, you can&apos;t move with it</source>
        <translation>A motort másolásra kényszerítik, nem mozgathatsz vele</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="508"/>
        <source>Destination</source>
        <translation>Cél</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="508"/>
        <source>Use the actual destination &quot;%1&quot;?</source>
        <translation>Használja a jelenlegi célt: &quot;%1&quot;?</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="732"/>
        <source>The mode has been forced previously. This is an internal error, please report it</source>
        <translation>Ezt a módot már korábban kényszerítették. Belső hiba történt, kérlek jelentsd be</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1062"/>
        <location filename="../../CopyEngine.cpp" line="1065"/>
        <location filename="../../CopyEngine.cpp" line="1070"/>
        <location filename="../../CopyEngine.cpp" line="1074"/>
        <source>Ask</source>
        <translation>Kérdezzen rá</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1063"/>
        <location filename="../../CopyEngine.cpp" line="1067"/>
        <location filename="../../CopyEngine.cpp" line="1071"/>
        <location filename="../../CopyEngine.cpp" line="1075"/>
        <source>Skip</source>
        <translation>Kihagy</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1066"/>
        <source>Merge</source>
        <translation>Összeolvaszt</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1068"/>
        <location filename="../../CopyEngine.cpp" line="1080"/>
        <source>Rename</source>
        <translation>Nevezze át</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1072"/>
        <source>Put at the end</source>
        <translation>Helyezze a végére</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1076"/>
        <source>Overwrite</source>
        <translation>Felülír</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1077"/>
        <source>Overwrite if different</source>
        <translation>Felülír, ha különbözik</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1078"/>
        <source>Overwrite if newer</source>
        <translation>Felülír, ha újabb</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1079"/>
        <source>Overwrite if older</source>
        <translation>Felülír, ha régebbi</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1082"/>
        <source>Automatic</source>
        <translation>Automatikus</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1083"/>
        <source>Sequential</source>
        <translation>Szekvenciális</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1084"/>
        <source>Parallel</source>
        <translation>Párhuzamos</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1185"/>
        <source>Options error</source>
        <translation>Beállítási hiba</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1185"/>
        <source>Options engine is not loaded. Unable to access the filters</source>
        <translation>A beállítási motor nincs betöltve. A szűrők elérése nem lehetséges</translation>
    </message>
</context>
<context>
    <name>CopyEngineFactory</name>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="427"/>
        <location filename="../../CopyEngineFactory.cpp" line="430"/>
        <location filename="../../CopyEngineFactory.cpp" line="435"/>
        <location filename="../../CopyEngineFactory.cpp" line="439"/>
        <source>Ask</source>
        <translation>Kérdezzen rá</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="428"/>
        <location filename="../../CopyEngineFactory.cpp" line="432"/>
        <location filename="../../CopyEngineFactory.cpp" line="436"/>
        <location filename="../../CopyEngineFactory.cpp" line="440"/>
        <source>Skip</source>
        <translation>Kihagy</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="431"/>
        <source>Merge</source>
        <translation>Összeolvaszt</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="433"/>
        <location filename="../../CopyEngineFactory.cpp" line="445"/>
        <source>Rename</source>
        <translation>Nevezze át</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="437"/>
        <source>Put at the end</source>
        <translation>Helyezze a végére</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="441"/>
        <source>Overwrite</source>
        <translation>Felülír</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="442"/>
        <source>Overwrite if different</source>
        <translation>Felülír, ha különbözik</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="443"/>
        <source>Overwrite if newer</source>
        <translation>Felülír, ha újabb</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="444"/>
        <source>Overwrite if older</source>
        <translation>Felülír, ha régebbi</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="447"/>
        <source>Automatic</source>
        <translation>Automatikus</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="448"/>
        <source>Sequential</source>
        <translation>Szekvenciális</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="449"/>
        <source>Parallel</source>
        <translation>Párhuzamos</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="500"/>
        <location filename="../../CopyEngineFactory.cpp" line="539"/>
        <source>Options error</source>
        <translation>Beállítási hiba</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="500"/>
        <source>Options engine is not loaded. Unable to access the filters</source>
        <translation>A beállítási motor nincs betöltve. A szűrők elérése nem lehetséges</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="539"/>
        <source>Options engine is not loaded, can&apos;t access to the filters</source>
        <translation>A beállítási motor nincs betöltve, a szűrők elérése nem lehetséges</translation>
    </message>
</context>
<context>
    <name>DiskSpace</name>
    <message>
        <location filename="../../DiskSpace.ui" line="14"/>
        <source>Disk space</source>
        <translation>Lemezterület</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.ui" line="24"/>
        <source>You need more space on this drive to finish this transfer</source>
        <translation>Több szabad helyre van szükséged ezen a lemezen az átvitel befejezéséhez</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.ui" line="49"/>
        <source>Continue</source>
        <translation>Folytatás</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.ui" line="56"/>
        <source>Cancel</source>
        <translation>Mégse</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.cpp" line="23"/>
        <source>Drives %1 have %2 available but need %3</source>
        <translation>%1 meghajtón %2 hely van, de %3 szükséges</translation>
    </message>
</context>
<context>
    <name>FileErrorDialog</name>
    <message>
        <location filename="../../FileErrorDialog.cpp" line="54"/>
        <source>Error on folder</source>
        <translation>Hiba a mappával</translation>
    </message>
    <message>
        <location filename="../../FileErrorDialog.cpp" line="57"/>
        <source>Folder name</source>
        <translation>Mappa neve</translation>
    </message>
</context>
<context>
    <name>FileExistsDialog</name>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="137"/>
        <source>%name% - copy%suffix%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="144"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="228"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="228"/>
        <source>Try rename with using special characters</source>
        <translation>Átnevezés speciális karakterek használatával</translation>
    </message>
</context>
<context>
    <name>FileIsSameDialog</name>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="111"/>
        <source>%name% - copy</source>
        <translation type="unfinished">%name% - másolás</translation>
    </message>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="118"/>
        <source>%name% - copy (%number%)</source>
        <translation type="unfinished">%name% - másolás (%number%)</translation>
    </message>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="184"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="184"/>
        <source>Try rename with using special characters</source>
        <translation>Átnevezés speciális karakterek használatával</translation>
    </message>
</context>
<context>
    <name>FilterRules</name>
    <message>
        <location filename="../../FilterRules.ui" line="17"/>
        <source>Filters dialog</source>
        <translation>Szűrők üzenet</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="33"/>
        <source>Search:</source>
        <translation>Keresés:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="43"/>
        <source>Search type:</source>
        <translation>Keresés típusa:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="51"/>
        <source>Raw text</source>
        <translation>Nyers szöveg</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="56"/>
        <source>Simplified regex</source>
        <translation>Egyszerűsített regex</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="61"/>
        <source>Perl&apos;s regex</source>
        <translation>Perl regex</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="69"/>
        <source>Apply on:</source>
        <translation>Alkalmazás ezen:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="77"/>
        <source>File</source>
        <translation>Fájl</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="82"/>
        <source>Folder</source>
        <translation>Mappa</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="87"/>
        <source>File and folder</source>
        <translation>Fájl és mappa</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="95"/>
        <source>Whole string must match</source>
        <translation>A teljes szövegnek egyeznie kell</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="125"/>
        <source>The test string matches with the regex</source>
        <translation>A tesztszöveg megegyezik a regexszel</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="102"/>
        <source>Checking</source>
        <translation>Ellenőrzés</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="108"/>
        <source>The regex is valid</source>
        <translation>A regex érvényes</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="115"/>
        <source>Test string:</source>
        <translation>Próbaszöveg:</translation>
    </message>
</context>
<context>
    <name>Filters</name>
    <message>
        <location filename="../../Filters.ui" line="14"/>
        <source>Filters</source>
        <translation>Szűrők</translation>
    </message>
    <message>
        <location filename="../../Filters.ui" line="30"/>
        <source>Exclusion filters</source>
        <translation>Kizáró szűrők</translation>
    </message>
    <message>
        <location filename="../../Filters.ui" line="93"/>
        <source>Inclusion filters</source>
        <translation>Használt szűrők</translation>
    </message>
    <message>
        <location filename="../../Filters.ui" line="105"/>
        <source>None = Include all</source>
        <translation>Nincs = Mindet használ</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="93"/>
        <location filename="../../Filters.cpp" line="131"/>
        <source>Raw text</source>
        <translation>Nyers szöveg</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="96"/>
        <location filename="../../Filters.cpp" line="134"/>
        <source>Simplified regex</source>
        <translation>Egyszerűsített regex</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="99"/>
        <location filename="../../Filters.cpp" line="137"/>
        <source>Perl&apos;s regex</source>
        <translation>Perl regex</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="107"/>
        <location filename="../../Filters.cpp" line="145"/>
        <source>Only on file</source>
        <translation>Csak fájlon</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="110"/>
        <location filename="../../Filters.cpp" line="148"/>
        <source>Only on folder</source>
        <translation>Csak mappán</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="116"/>
        <location filename="../../Filters.cpp" line="154"/>
        <location filename="../../Filters.cpp" line="216"/>
        <location filename="../../Filters.cpp" line="255"/>
        <source>Full match</source>
        <translation>Teljes egyezés</translation>
    </message>
</context>
<context>
    <name>FolderExistsDialog</name>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="57"/>
        <source>Folder already exists</source>
        <translation>Mappa már létezik</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="122"/>
        <source>%name% - copy</source>
        <translation type="unfinished">%name% - másolás</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="131"/>
        <source>%name% - copy (%number%)</source>
        <translation type="unfinished">%name% - másolás (%number%)</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="190"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="190"/>
        <source>Try rename with using special characters</source>
        <translation>Átnevezés speciális karakterek használatával</translation>
    </message>
</context>
<context>
    <name>ListThread</name>
    <message>
        <location filename="../../ListThread.cpp" line="1487"/>
        <location filename="../../ListThread.cpp" line="2419"/>
        <source>Unable do to move or copy item into wrong forced mode: %1</source>
        <translation>Elem másolása vagy mozgatás nem lehetséges a hibás kényszerített módban: %1</translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1494"/>
        <location filename="../../ListThread.cpp" line="2426"/>
        <source>Unable to save the transfer list: %1</source>
        <translation>Átviteli lista mentése nem lehetséges: %1</translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1510"/>
        <source>Problem reading file, or file-size is 0</source>
        <translation>Hiba a fájl olvasásánál vagy a fálméret 0</translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1517"/>
        <source>Wrong header: &quot;%1&quot;</source>
        <translation>Hibás fejléc: &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1526"/>
        <source>The transfer list is in mixed mode, but this instance is not in this mode</source>
        <translation>Az átviteli lista kevert módban van, de ez a példány nincs</translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1535"/>
        <source>The transfer list is in copy mode, but this instance is not in this mode</source>
        <translation>Az átviteli lista másolás módban van, de ez a példány nincs</translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1541"/>
        <source>The transfer list is in move mode, but this instance is not in this mode</source>
        <translation>Az átviteli lista mozgatás módban van, de ez a példány nincs</translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1604"/>
        <source>Some errors have been found during the line parsing</source>
        <translation>Néhány hiba történt a sorelemzés során</translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1612"/>
        <source>Unable to open the transfer list: %1</source>
        <translation>Az átviteli lista megnyitása nem lehetséges: %1</translation>
    </message>
</context>
<context>
    <name>MkPath</name>
    <message>
        <location filename="../../MkPath.cpp" line="142"/>
        <source>Unable to create the folder</source>
        <translation>Mappa létrehozása nem lehetséges</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="155"/>
        <source>The source folder don&apos;t exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="183"/>
        <source>Unable to temporary rename the folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="206"/>
        <source>Unable to do the final real move the folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="233"/>
        <source>Unable to move the folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="93"/>
        <location filename="../../MkPath.cpp" line="276"/>
        <source>Unable to remove</source>
        <translation>Eltávolítás nem lehetséges</translation>
    </message>
</context>
<context>
    <name>ReadThread</name>
    <message>
        <location filename="../../ReadThread.cpp" line="59"/>
        <source>Internal error, please report it!</source>
        <translation>Belső hiba, kérlek jelentsd!</translation>
    </message>
    <message>
        <location filename="../../ReadThread.cpp" line="188"/>
        <source>Internal error reading the source file:block size out of range</source>
        <translation>Belső hiba történt a forrásfájl olvasásakor: a blokkméret tartományon kívüli</translation>
    </message>
    <message>
        <location filename="../../ReadThread.cpp" line="196"/>
        <location filename="../../ReadThread.cpp" line="420"/>
        <source>Unable to read the source file: </source>
        <translation>A forrásfájl olvasása nem lehetséges:</translation>
    </message>
    <message>
        <location filename="../../ReadThread.cpp" line="237"/>
        <location filename="../../ReadThread.cpp" line="468"/>
        <source>File truncated during the read, possible data change</source>
        <translation>A fájl olvasás során megcsonkult, valószínűleg adatváltozás miatt</translation>
    </message>
</context>
<context>
    <name>RenamingRules</name>
    <message>
        <location filename="../../RenamingRules.ui" line="14"/>
        <source>Renaming rules</source>
        <translation>Átnevezési szabályok</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="35"/>
        <source>First renaming</source>
        <translation>Első átnevezés</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="41"/>
        <source>%name% - copy%suffix%</source>
        <extracomment>%name% should not be translated</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="57"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <extracomment>%name%, %number% should not be translated</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="67"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Variables: &lt;span style=&quot; font-weight:600;&quot;&gt;%name%&lt;/span&gt; for the original file name, &lt;span style=&quot; font-weight:600;&quot;&gt;%number%&lt;/span&gt; for the extra number, &lt;span style=&quot; font-weight:600;&quot;&gt;%suffix%&lt;/span&gt; file suffix&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>%name%, %number% should not be translated</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="51"/>
        <source>Second renaming</source>
        <translation>Második átnevezés</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.cpp" line="39"/>
        <location filename="../../RenamingRules.cpp" line="62"/>
        <source>%1 - copy</source>
        <translation>%1 - másolás</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.cpp" line="43"/>
        <location filename="../../RenamingRules.cpp" line="73"/>
        <source>%1 - copy (%2)</source>
        <translation>%1 - másolás (%2)</translation>
    </message>
</context>
<context>
    <name>ScanFileOrFolder</name>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="274"/>
        <source>Blacklisted folder</source>
        <translation>Feketelistás mappa</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="338"/>
        <source>%1 - copy</source>
        <translation>%1 - másolás</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="345"/>
        <source>%1 - copy (%2)</source>
        <translation>%1 - másolás (%2)</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="401"/>
        <source>%name% - copy</source>
        <translation type="unfinished">%name% - másolás</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="408"/>
        <source>%name% - copy (%number%)</source>
        <translation type="unfinished">%name% - másolás (%number%)</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="444"/>
        <source>This is not a folder</source>
        <translation>Ez nem mappa</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="446"/>
        <source>The folder does exists</source>
        <translation>A mappa létezik</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="448"/>
        <source>The folder is not readable</source>
        <translation>A mappa nem olvasható</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="459"/>
        <source>Problem with name encoding</source>
        <translation>Probléma a névkódolással</translation>
    </message>
</context>
<context>
    <name>TransferThread</name>
    <message>
        <location filename="../../TransferThread.cpp" line="244"/>
        <location filename="../../TransferThread.cpp" line="673"/>
        <location filename="../../TransferThread.cpp" line="745"/>
        <location filename="../../TransferThread.cpp" line="1315"/>
        <source>File not found</source>
        <translation>Fájl nem található</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="586"/>
        <source>Drive %1</source>
        <translation type="unfinished">%1 meghajtó</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="588"/>
        <source>Unknown folder</source>
        <translation type="unfinished">Ismeretlen mappa</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="592"/>
        <source>root</source>
        <translation type="unfinished">gyökér</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="787"/>
        <source>The source doesn&apos;t exist</source>
        <translation type="unfinished">A forrás nem létezik</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="751"/>
        <location filename="../../TransferThread.cpp" line="838"/>
        <source>Unable to do the folder</source>
        <translation type="unfinished">Mappaművelet nem lehetséges</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="228"/>
        <source>Try rename with using special characters</source>
        <translation>Átnevezés speciális karakterek használatával</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="346"/>
        <location filename="../../TransferThread.cpp" line="363"/>
        <source>Wrong modification date or unable to get it, you can disable time transfer to do it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="421"/>
        <location filename="../../TransferThread.cpp" line="444"/>
        <source>Internal error: Already opening</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="645"/>
        <source>%name% - copy</source>
        <translation type="unfinished">%name% - másolás</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="652"/>
        <source>%name% - copy (%number%)</source>
        <translation type="unfinished">%name% - másolás (%number%)</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="711"/>
        <location filename="../../TransferThread.cpp" line="826"/>
        <source>The source file doesn&apos;t exist</source>
        <translation type="unfinished">A forrásfájl nem létezik</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="832"/>
        <source>Another file exists at same place</source>
        <translation type="unfinished">Egy másik fájl létezik ugyanazon a helyen</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="1134"/>
        <source>The checksums do not match</source>
        <translation type="unfinished">A checksumok nem egyeznek meg</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="1224"/>
        <source>Internal error: The destination is not closed</source>
        <translation type="unfinished">Belső hiba: a cél nincs bezárva</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="1239"/>
        <source>Internal error: The size transfered doesn&apos;t match</source>
        <translation type="unfinished">Belső hiba: az átvitt méret nem egyezik meg</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="1250"/>
        <source>Internal error: The buffer is not empty</source>
        <translation type="unfinished">Belső hiba: a puffer nem üres</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="1315"/>
        <location filename="../../TransferThread.cpp" line="1333"/>
        <location filename="../../TransferThread.cpp" line="1348"/>
        <source>Unable to change the date</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WriteThread</name>
    <message>
        <location filename="../../WriteThread.cpp" line="83"/>
        <source>Path resolution error (Empty path)</source>
        <translation>Útvonal feloldási hiba (Üres útvonal)</translation>
    </message>
    <message>
        <location filename="../../WriteThread.cpp" line="277"/>
        <source>Internal error, please report it!</source>
        <translation>Belső hiba, kérlek jelentsd!</translation>
    </message>
    <message>
        <location filename="../../WriteThread.cpp" line="680"/>
        <source>Unable to read the source file: </source>
        <translation>A forrásfájl olvasása nem lehetséges:</translation>
    </message>
    <message>
        <location filename="../../WriteThread.cpp" line="705"/>
        <source>File truncated during read, possible data change</source>
        <translation>Fájl megsérült az olvasás közben, valószínűleg adatváltozás</translation>
    </message>
</context>
<context>
    <name>copyEngineOptions</name>
    <message>
        <location filename="../../copyEngineOptions.ui" line="44"/>
        <source>Transfer</source>
        <translation>Átvitel</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="53"/>
        <source>Move the whole folder</source>
        <translation>Mozgassa át az egész mappát</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="60"/>
        <source>Transfer the file rights</source>
        <translation>Fájljogok átadása</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="70"/>
        <source>Keep the file date</source>
        <translation>Fájl dátumának megtartása</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="83"/>
        <source>Autostart the transfer</source>
        <translation>Átvitel automatikus indítása</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="90"/>
        <location filename="../../copyEngineOptions.ui" line="110"/>
        <source>Less performance if checked</source>
        <translation>Kisebb teljesítmény, ha be van jelölve</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="113"/>
        <source>Follow the strict order</source>
        <translation>Kövesse a szigorú sorrendet</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="139"/>
        <source>Error and collision</source>
        <translation>Hiba és ütközés</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="145"/>
        <source>When folder error</source>
        <translation>Mappa hiba esetén</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="155"/>
        <source>When file error</source>
        <translation>Fájl hiba esetén</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="181"/>
        <source>When file collision</source>
        <translation>Fájl ütközés esetén</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="241"/>
        <source>When folder collision</source>
        <translation>Mappa ütközés esetén</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="272"/>
        <source>Check if destination folder exists</source>
        <translation>Célmappa létezésének ellenőrzése</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="279"/>
        <source>Renaming rules</source>
        <translation>Átnevezési szabályok</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="299"/>
        <source>Delete partially transferred files</source>
        <translation>Részben átvitt fájlok törlése</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="312"/>
        <source>Rename the original destination</source>
        <translation>Eredeti cél átnevezése</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="343"/>
        <source>Control</source>
        <translation>Irányítás</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="349"/>
        <source>Checksum</source>
        <translation>Checksum</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="358"/>
        <source>Only after error</source>
        <translation>Csak hiba után</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="365"/>
        <source>Ignore if impossible</source>
        <translation>Hagyja ki, ha nem lehetséges</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="382"/>
        <source>Verify checksums</source>
        <translation>Checksumok ellenőrzése</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="414"/>
        <source>Performance</source>
        <translation>Teljesítmény</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="420"/>
        <source>Parallel buffer</source>
        <translation>Párhuzamos puffer</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="427"/>
        <location filename="../../copyEngineOptions.ui" line="440"/>
        <location filename="../../copyEngineOptions.ui" line="453"/>
        <location filename="../../copyEngineOptions.ui" line="490"/>
        <location filename="../../copyEngineOptions.ui" line="559"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="469"/>
        <source>Block size</source>
        <translation>Blokkméret</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="476"/>
        <source>Sequential buffer</source>
        <translation>Szekvenciális puffer</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="483"/>
        <source>Enable OS buffer</source>
        <translation>OS puffer engedélyezése</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="506"/>
        <source>OS buffer only if smaller than</source>
        <translation>OS buffer csak akkor, ha kisebb mint</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="513"/>
        <source>Transfer algorithm</source>
        <translation>Átviteli algoritmus</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="552"/>
        <source>Parallelize if smaller than</source>
        <translation>Párhuzamosítás, ha kisebb mint</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="582"/>
        <source>Inode threads (unsafe &gt; 1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="589"/>
        <location filename="../../copyEngineOptions.ui" line="599"/>
        <source>More cpu, but better organisation on the disk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="602"/>
        <source>Order the list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="618"/>
        <source>Misc</source>
        <translation>Egyéb</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="624"/>
        <source>Check the disk space</source>
        <translation>Lemezterület ellenőrzése</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="634"/>
        <source>Use this folder when destination is not set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="646"/>
        <source>Browse</source>
        <translation>Tallózás</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="668"/>
        <source>Filters</source>
        <translation>Szűrők</translation>
    </message>
</context>
<context>
    <name>fileErrorDialog</name>
    <message>
        <location filename="../../fileErrorDialog.ui" line="14"/>
        <source>Error with file</source>
        <translation>Hiba a fájllal</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="20"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="59"/>
        <source>Size</source>
        <translation>Méret</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="76"/>
        <source>Modified</source>
        <translation>Módosítva</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="93"/>
        <source>File name</source>
        <translation>Fájlnév</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="110"/>
        <source>Destination</source>
        <translation>Cél</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="127"/>
        <source>Folder</source>
        <translation>Mappa</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="173"/>
        <source>&amp;Always perform this action</source>
        <translation>&amp;Mindig hajtsa végre ezt a műveletet</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="193"/>
        <source>Try in with elevated privileges</source>
        <translation>Próbálja meg emelt jogosultsággal</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="200"/>
        <source>Put to bottom</source>
        <translation>Tegye legalulra</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="207"/>
        <source>Retry</source>
        <translation>Újra</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="214"/>
        <source>&amp;Skip</source>
        <translation>&amp;Kihagy</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="221"/>
        <source>&amp;Cancel</source>
        <translation>M&amp;égse</translation>
    </message>
</context>
<context>
    <name>fileExistsDialog</name>
    <message>
        <location filename="../../fileExistsDialog.ui" line="14"/>
        <source>The file exists</source>
        <translation>A fájl létezik</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="34"/>
        <source>Source</source>
        <translation>Forrás</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="50"/>
        <source>Destination</source>
        <translation>Cél</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="82"/>
        <location filename="../../fileExistsDialog.ui" line="170"/>
        <source>Size</source>
        <translation>Méret</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="99"/>
        <location filename="../../fileExistsDialog.ui" line="187"/>
        <source>Modified</source>
        <translation>Módosítva</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="116"/>
        <location filename="../../fileExistsDialog.ui" line="204"/>
        <source>File name</source>
        <translation>Fájlnév</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="133"/>
        <location filename="../../fileExistsDialog.ui" line="221"/>
        <source>Folder</source>
        <translation>Mappa</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="277"/>
        <source>Suggest new &amp;name</source>
        <translation>Új &amp;név ajánlása</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="288"/>
        <source>&amp;Always perform this action</source>
        <translation>&amp;Mindig hajtsa végre ezt a műveletet</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="346"/>
        <location filename="../../fileExistsDialog.ui" line="349"/>
        <source>Overwrite if modification date differs</source>
        <translation>Felülír, ha a módosítás dátuma különbözik</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="354"/>
        <location filename="../../fileExistsDialog.ui" line="357"/>
        <source>Overwrite if older</source>
        <translation>Felülír, ha régebbi</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="308"/>
        <source>&amp;Rename</source>
        <translation>&amp;Átnevez</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="315"/>
        <source>&amp;Overwrite</source>
        <translation>&amp;Felülír</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="325"/>
        <source>&amp;Skip</source>
        <translation>&amp;Kihagy</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="332"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Mégse</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="341"/>
        <source>Overwrite if newer</source>
        <translation>Felülír, ha újabb</translation>
    </message>
</context>
<context>
    <name>fileIsSameDialog</name>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="40"/>
        <source>Size</source>
        <translation>Méret</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="110"/>
        <source>Modified</source>
        <translation>Módosítva</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="70"/>
        <source>File name</source>
        <translation>Fájlnév</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="14"/>
        <source>The source and destination are same</source>
        <translation>A forrás és a cél megegyezik</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="90"/>
        <source>Folder</source>
        <translation>Mappa</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="159"/>
        <source>Suggest new &amp;name</source>
        <translation>Új &amp;név javasolása</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="170"/>
        <source>&amp;Always perform this action</source>
        <translation>&amp;Mindig hajtsa végre ezt a műveletet</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="190"/>
        <source>&amp;Rename</source>
        <translation>&amp;Átnevez</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="197"/>
        <source>&amp;Skip</source>
        <translation>&amp;Kihagy</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="204"/>
        <source>&amp;Cancel</source>
        <translation>M&amp;égse</translation>
    </message>
</context>
<context>
    <name>folderExistsDialog</name>
    <message>
        <location filename="../../folderExistsDialog.ui" line="34"/>
        <source>Source</source>
        <translation>Forrás</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="50"/>
        <source>Destination</source>
        <translation>Cél</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="82"/>
        <location filename="../../folderExistsDialog.ui" line="150"/>
        <source>Modified</source>
        <translation>Módosítva</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="99"/>
        <location filename="../../folderExistsDialog.ui" line="160"/>
        <source>Folder name</source>
        <translation>Mappa neve</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="227"/>
        <source>Suggest new &amp;name</source>
        <translation>Új &amp;név javasolása</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="14"/>
        <source>The source and destination is identical</source>
        <translation>A forrás és a cél megegyezik</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="116"/>
        <location filename="../../folderExistsDialog.ui" line="184"/>
        <source>Folder</source>
        <translation>Mappa</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="238"/>
        <source>&amp;Always perform this action</source>
        <translation>&amp;Mindig hajtsa végre ezt a műveletet</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="245"/>
        <source>&amp;Rename</source>
        <translation>&amp;Átnevez</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="252"/>
        <source>Merge</source>
        <translation>Összeolvaszt</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="259"/>
        <source>Skip</source>
        <translation>Kihagy</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="266"/>
        <source>&amp;Cancel</source>
        <translation>M&amp;égse</translation>
    </message>
</context>
</TS>
